permutation_character

Function permutation_character 

pub fn permutation_character(
    degree: usize,
    gens: &[Perm],
    cap: usize,
) -> Option<Vec<u128>>
The permutation character π(g) = #{points fixed by g} of the natural action of ⟨gens⟩ on its degree points, valued per conjugacy class (a class invariant, since conjugate permutations have the same cycle type). The character of the permutation representation ℂ^degree. Aligned with the conjugacy classes (so with CharacterTable’s columns). None when |G| > cap.